@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: Copyright (c) 2022 Dan Halbert for Adafruit Industries
+# SPDX-FileCopyrightText: Copyright (c) 2022 Dan Halbert for Adafruit Industries, Michał Pokusa
 #
 # SPDX-License-Identifier: MIT
 """
@@ -19,12 +19,13 @@ Implementation Notes
   https://github.com/adafruit/circuitpython/releases
 """
 
-__version__ = "4.0.1"
+__version__ = "4.4.1"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_HTTPServer.git"
 
 
 from .authentication import (
     Basic,
+    Token,
     Bearer,
     check_authentication,
     require_authentication,
@@ -51,22 +52,34 @@ from .methods import (
     CONNECT,
 )
 from .mime_types import MIMETypes
-from .request import Request
+from .request import QueryParams, FormData, Request
 from .response import (
     Response,
     FileResponse,
     ChunkedResponse,
     JSONResponse,
     Redirect,
+    SSEResponse,
+    Websocket,
+)
+from .route import Route, as_route
+from .server import (
+    Server,
+    NO_REQUEST,
+    CONNECTION_TIMED_OUT,
+    REQUEST_HANDLED_NO_RESPONSE,
+    REQUEST_HANDLED_RESPONSE_SENT,
 )
-from .server import Server
 from .status import (
     Status,
+    SWITCHING_PROTOCOLS_101,
     OK_200,
     CREATED_201,
     ACCEPTED_202,
     NO_CONTENT_204,
     PARTIAL_CONTENT_206,
+    MOVED_PERMANENTLY_301,
+    FOUND_302,
     TEMPORARY_REDIRECT_307,
     PERMANENT_REDIRECT_308,
     BAD_REQUEST_400,
